/***************************************************************************
                          liblaus.h  -  description
                             -------------------
    copyright            : (C) 2003 by Thomas Biege / SuSE Linux AG
    email                : thomas@suse.de
 ***************************************************************************/

#ifndef __LAUS_HDR__
#define __LAUS_HDR__

#include <errno.h>
#include <sys/types.h>
#include <audit.h>

#ifdef __cplusplus
extern "C" {
#endif

#define LAUS_VERSION		0x20030807

#define PATH_FILTER_CONFIG	PATH_CONFIG_DIR "/filter.conf"

/*
 * File header of the audit log file
 */
struct laus_file_header {
	u_int32_t		h_version;
	u_int32_t		h_msgversion;
	u_int32_t		h_count;	/* 0 for stream files */
	char			h_hostname[256];
};

/*
 * Record headers used in the audit log file
 */
struct laus_record_header {
	time_t			r_time;
	size_t			r_size;

	/* Followed by kernel message */
};

/* Flags for laus_exec() */
#define LAUS_FLG_NONE		0x0000
#define LAUS_FLG_DETACH		0x0001		/* detach child-process */


/* ID Numbers for Audit-Session-ID to identify a Service */
#define LAUS_ASID_LOGIN		0x0001
#define LAUS_ASID_SSHD		0x0002
#define LAUS_ASID_FTPD		0x0003


/* Our public functions */
extern int		laus_init(void);
extern int		laus_open(char *dev_file);
extern int		laus_registerauditdaemon(void);
extern pid_t		laus_exec(int flags, char *prog, ...);
extern int		laus_attach(void);
extern int		laus_detach(void);
extern int		laus_suspend(void);
extern int		laus_resume(void);
extern int		laus_setauditid(void);
extern int		laus_setsession(uid_t uid,
				const char *hostname,
				const char *hostaddr,
				const char *terminal);
extern int		laus_setauditdaemon(void);
extern int		laus_clrpolicy(void);
extern int		laus_setpolicy(int syscall, int policy, int filter);
extern int		laus_clrfilter(void);
extern int		laus_setfilter(struct audit_filter *filter);
extern int		laus_read(void *buffer, size_t size);
extern const char *	laus_strerror(int code);
extern int		laus_log(const char *audit_tag, const char *fmt, ...);
extern int		laus_textmessage(const char *);
extern int		laus_usermessage(int, const void *, size_t);
extern int		laus_close(void);


#ifdef __cplusplus
}; // end of extern "C"
#endif

#endif

